Struct style::properties::shorthands::flex::LonghandsToSerialize
[−]
[src]
pub struct LonghandsToSerialize<'a> {
pub flex_grow: &'a SpecifiedValue,
pub flex_shrink: &'a SpecifiedValue,
pub flex_basis: &'a SpecifiedValue,
}Represents a serializable set of all of the longhand properties that correspond to a shorthand.
Fields
flex_grow: &'a SpecifiedValue
flex_shrink: &'a SpecifiedValue
flex_basis: &'a SpecifiedValue
Methods
impl<'a> LonghandsToSerialize<'a>[src]
pub fn from_iter<I>(iter: I) -> Result<Self, ()> where
I: Iterator<Item = &'a PropertyDeclaration>, [src]
I: Iterator<Item = &'a PropertyDeclaration>,
Tries to get a serializable set of longhands given a set of property declarations.